@@ -11,12 +11,19 @@ Would results in:
 """
 import logging
 
+from nio import MatrixRoom, RoomMessage
+
 from chaanbot import command_utility
+from chaanbot.database import Database
+from chaanbot.matrix import Matrix
 
 logger = logging.getLogger("ping")
 
 
 class Alive:
+    def __init__(self, config, matrix: Matrix, database: Database, requests):
+        self.matrix = matrix
+
     always_run = False
     operations = {
         "alive": {
@@ -24,9 +31,9 @@ class Alive:
         }
     }
 
-    def run(self, room, event, message) -> bool:
+    async def run(self, room: MatrixRoom, event: RoomMessage, message) -> bool:
         if self.should_run(message):
-            room.send_text("Yes.")
+            await self.matrix.send_text_to_room("Yes.", room.room_id)
             return True
         return False
 
